# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/green_tag/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\GreenTag\\": "packages/litecms/green_tag/src",
            "Litecms\\GreenTag\\Seeders\\": "packages/litecms/green_tag/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\GreenTag\Providers\GreenTagServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'GreenTag'  => Litecms\GreenTag\Facades\GreenTag::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\GreenTag\\Seeders\\GreenTagTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\GreenTag\Providers\GreenTagServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\GreenTag\Providers\GreenTagServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\GreenTag\Providers\GreenTagServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/green_tag/{modulename}

**User**

    http://path-to-route-folder/user/green_tag/{modulename}

**Public**

    http://path-to-route-folder/green_tags


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/green_tag/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/green_tag/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/green_tag/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/green_tag/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/green_tag/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/green_tag/{modulename}/{slug}
    METHOD: GET