<?php

namespace Litecms\GreenTag\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\GreenTag\Forms\GreenTag as GreenTagForm;
use Litecms\GreenTag\Http\Requests\GreenTagRequest;
use Litecms\GreenTag\Interfaces\GreenTagRepositoryInterface;
use Litecms\GreenTag\Repositories\Eloquent\Filters\GreenTagResourceFilter;
use Litecms\GreenTag\Repositories\Eloquent\Presenters\GreenTagListPresenter;

/**
 * Resource controller class for green_tag.
 */
class GreenTagResourceController extends BaseController
{

    /**
     * Initialize green_tag resource controller.
     *
     *
     * @return null
     */
    public function __construct(GreenTagRepositoryInterface $green_tag)
    {
        parent::__construct();
        $this->form = GreenTagForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.green_tag.modules'), 'green_tag', guard_url('green_tag'));
        $this->repository = $green_tag;
    }

    /**
     * Display a list of green_tag.
     *
     * @return Response
     */
    public function index(GreenTagRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(GreenTagResourceFilter::class)
            ->setPresenter(GreenTagListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('green_tag::green_tag.names'))
            ->view('green_tag::green_tag.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display green_tag.
     *
     * @param Request $request
     * @param Model   $green_tag
     *
     * @return Response
     */
    public function show(GreenTagRequest $request, GreenTagRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('green_tag::green_tag.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('green_tag::green_tag.show')
            ->output();
    }

    /**
     * Show the form for creating a new green_tag.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(GreenTagRequest $request, GreenTagRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('green_tag::green_tag.name'))
            ->view('green_tag::green_tag.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new green_tag.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(GreenTagRequest $request, GreenTagRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('green_tag::green_tag.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('green_tag/green_tag/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/green_tag/green_tag'))
                ->redirect();
        }

    }

    /**
     * Show green_tag for editing.
     *
     * @param Request $request
     * @param Model   $green_tag
     *
     * @return Response
     */
    public function edit(GreenTagRequest $request, GreenTagRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('green_tag::green_tag.name'))
            ->view('green_tag::green_tag.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the green_tag.
     *
     * @param Request $request
     * @param Model   $green_tag
     *
     * @return Response
     */
    public function update(GreenTagRequest $request, GreenTagRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('green_tag::green_tag.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('green_tag/green_tag/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('green_tag/green_tag/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the green_tag.
     *
     * @param Model   $green_tag
     *
     * @return Response
     */
    public function destroy(GreenTagRequest $request, GreenTagRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('green_tag::green_tag.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('green_tag/green_tag/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('green_tag/green_tag/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
