<?php

namespace Litecms\GreenTag\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\GreenTag\Models\GreenTag;

class GreenTagPolicy
{

    /**
     * Determine if the given user can view the green_tag.
     *
     * @param UserPolicyInterface $authUser
     * @param GreenTag $green_tag
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, GreenTag $green_tag)
    {
        if ($authUser->canDo('green_tag.green_tag.view') && $authUser->isAdmin()) {
            return true;
        }

        return $green_tag->user_id == user_id() && $green_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can create a green_tag.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('green_tag.green_tag.create');
    }

    /**
     * Determine if the given user can update the given green_tag.
     *
     * @param UserPolicyInterface $authUser
     * @param GreenTag $green_tag
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, GreenTag $green_tag)
    {
        if ($authUser->canDo('green_tag.green_tag.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $green_tag->user_id == user_id() && $green_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given green_tag.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, GreenTag $green_tag)
    {
        return $green_tag->user_id == user_id() && $green_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given green_tag.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, GreenTag $green_tag)
    {
        if ($authUser->canDo('green_tag.green_tag.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given green_tag.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, GreenTag $green_tag)
    {
        if ($authUser->canDo('green_tag.green_tag.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
