<?php

namespace Litecms\GreenTag\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\GreenTag\Models\GreenTagProductHealthBenefits;

class GreenTagProductHealthBenefitsPolicy
{

    /**
     * Determine if the given user can view the green_tag_product_health_benefits.
     *
     * @param UserPolicyInterface $authUser
     * @param GreenTagProductHealthBenefits $green_tag_product_health_benefits
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, GreenTagProductHealthBenefits $green_tag_product_health_benefits)
    {
        if ($authUser->canDo('green_tag.green_tag_product_health_benefits.view') && $authUser->isAdmin()) {
            return true;
        }

        return $green_tag_product_health_benefits->user_id == user_id() && $green_tag_product_health_benefits->user_type == user_type();
    }

    /**
     * Determine if the given user can create a green_tag_product_health_benefits.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('green_tag.green_tag_product_health_benefits.create');
    }

    /**
     * Determine if the given user can update the given green_tag_product_health_benefits.
     *
     * @param UserPolicyInterface $authUser
     * @param GreenTagProductHealthBenefits $green_tag_product_health_benefits
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, GreenTagProductHealthBenefits $green_tag_product_health_benefits)
    {
        if ($authUser->canDo('green_tag.green_tag_product_health_benefits.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $green_tag_product_health_benefits->user_id == user_id() && $green_tag_product_health_benefits->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given green_tag_product_health_benefits.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, GreenTagProductHealthBenefits $green_tag_product_health_benefits)
    {
        return $green_tag_product_health_benefits->user_id == user_id() && $green_tag_product_health_benefits->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given green_tag_product_health_benefits.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, GreenTagProductHealthBenefits $green_tag_product_health_benefits)
    {
        if ($authUser->canDo('green_tag.green_tag_product_health_benefits.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given green_tag_product_health_benefits.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, GreenTagProductHealthBenefits $green_tag_product_health_benefits)
    {
        if ($authUser->canDo('green_tag.green_tag_product_health_benefits.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
