<?php

namespace Litecms\GreenTag\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\GreenTag\Models\GreenTagProductSegments;

class GreenTagProductSegmentsPolicy
{

    /**
     * Determine if the given user can view the green_tag_product_segments.
     *
     * @param UserPolicyInterface $authUser
     * @param GreenTagProductSegments $green_tag_product_segments
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, GreenTagProductSegments $green_tag_product_segments)
    {
        if ($authUser->canDo('green_tag.green_tag_product_segments.view') && $authUser->isAdmin()) {
            return true;
        }

        return $green_tag_product_segments->user_id == user_id() && $green_tag_product_segments->user_type == user_type();
    }

    /**
     * Determine if the given user can create a green_tag_product_segments.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('green_tag.green_tag_product_segments.create');
    }

    /**
     * Determine if the given user can update the given green_tag_product_segments.
     *
     * @param UserPolicyInterface $authUser
     * @param GreenTagProductSegments $green_tag_product_segments
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, GreenTagProductSegments $green_tag_product_segments)
    {
        if ($authUser->canDo('green_tag.green_tag_product_segments.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $green_tag_product_segments->user_id == user_id() && $green_tag_product_segments->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given green_tag_product_segments.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, GreenTagProductSegments $green_tag_product_segments)
    {
        return $green_tag_product_segments->user_id == user_id() && $green_tag_product_segments->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given green_tag_product_segments.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, GreenTagProductSegments $green_tag_product_segments)
    {
        if ($authUser->canDo('green_tag.green_tag_product_segments.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given green_tag_product_segments.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, GreenTagProductSegments $green_tag_product_segments)
    {
        if ($authUser->canDo('green_tag.green_tag_product_segments.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
