<?php

namespace Litecms\GreenTag\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litecms\GreenTag\Models\GreenTag;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\GreenTag\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/green_tag/green_tag/*')) {
            Route::bind('green_tag', function ($green_tag) {
                $green_tagRepo = $this->app->make('Litecms\GreenTag\Interfaces\GreenTagRepositoryInterface');
                return $green_tagRepo->findorNew($green_tag);
            });
        }
        if (Request::is('*/green_tag/green_tag_segments/*')) {
            Route::bind('green_tag_segments', function ($green_tag_segments) {
                $green_tag_segmentsRepo = $this->app->make('Litecms\GreenTag\Interfaces\GreenTagSegmentsRepositoryInterface');
                return $green_tag_segmentsRepo->findorNew($green_tag_segments);
            });
        }
        if (Request::is('*/green_tag/green_tag_health_benefits/*')) {
            Route::bind('green_tag_health_benefits', function ($green_tag_health_benefits) {
                $green_tag_health_benefitsRepo = $this->app->make('Litecms\GreenTag\Interfaces\GreenTagHealthBenefitsRepositoryInterface');
                return $green_tag_health_benefitsRepo->findorNew($green_tag_health_benefits);
            });
        }
        if (Request::is('*/green_tag/green_tag_product_health_benefits/*')) {
            Route::bind('green_tag_product_health_benefits', function ($green_tag_product_health_benefits) {
                $green_tag_product_health_benefitsRepo = $this->app->make('Litecms\GreenTag\Interfaces\GreenTagProductHealthBenefitsRepositoryInterface');
                return $green_tag_product_health_benefitsRepo->findorNew($green_tag_product_health_benefits);
            });
        }
        if (Request::is('*/green_tag/green_tag_product_segments/*')) {
            Route::bind('green_tag_product_segments', function ($green_tag_product_segments) {
                $green_tag_product_segmentsRepo = $this->app->make('Litecms\GreenTag\Interfaces\GreenTagProductSegmentsRepositoryInterface');
                return $green_tag_product_segmentsRepo->findorNew($green_tag_product_segments);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
